# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from . import models


class PriceListAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {'fields': (
            'code', 'name', 'slug',
            'price_list_type', 'currency'
        )}),
        (_('date admin'), {'fields': (('date_begin', 'date_end',),)}),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'code', 'name',
        'date_begin', 'date_end', 'ordering',
    )
    search_fields = ('name', 'code')
    prepopulated_fields = {'slug': ('name',)}
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class PriceListItemAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {'fields': (
            'price_list', 'product', 'price',
            'vat', 'price_tax_included',
            'discount1', 'discount2', 'recharge',
            'min_quantity', 'max_quantity',
        )}),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'get_price_list_code', 'product',
        'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity',
    )
    search_fields = ('product__name', 'product__code')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = _("PLC")
    get_price_list_code.admin_order_field = 'price_list.code'


class OrganizationPriceListAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'price_list', 'organization', 'discount1', 'discount2', 'recharge',
            ),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('organization__code', 'organization__name',)
    list_display = (
        'status', 'get_organization_code', 'get_organization_name',
        'get_price_list_code', 'get_price_list_name',
        'discount1', 'discount2', 'recharge',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)

    def get_organization_code(self, obj):
        return obj.organization.code
    get_organization_code.short_description = _('organization code')
    get_organization_code.admin_order_field = 'organization.code'
    get_organization_code.allow_tags = True

    def get_organization_name(self, obj):
        return obj.organization.name
    get_organization_name.short_description = _('organization name')
    get_organization_name.admin_order_field = 'organization.name'
    get_organization_name.allow_tags = True

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = _('price list code')
    get_price_list_code.admin_order_field = 'price_list.code'
    get_price_list_code.allow_tags = True

    def get_price_list_name(self, obj):
        return obj.price_list.name
    get_price_list_name.short_description = _('price list name')
    get_price_list_name.admin_order_field = 'price_list.name'
    get_price_list_name.allow_tags = True


admin.site.register(models.PriceList, PriceListAdmin)
admin.site.register(models.PriceListItem, PriceListItemAdmin)
admin.site.register(models.OrganizationPriceList, OrganizationPriceListAdmin)
