# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class PriceListList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceList.objects.all()
    serializer_class = serializers.PriceListSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(PriceListList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class PriceListRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceList.objects.all()
    serializer_class = serializers.PriceListSerializer


class PriceListCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceList.objects.all()
    serializer_class = serializers.PriceListSerializerCreate


class PriceListUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceList.objects.all()
    serializer_class = serializers.PriceListSerializerUpdate


class PriceListItemList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceListItem.objects.all()
    serializer_class = serializers.PriceListItemSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(PriceListItemList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class PriceListItemRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceListItem.objects.all()
    serializer_class = serializers.PriceListItemSerializer


class PriceListItemCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceListItem.objects.all()
    serializer_class = serializers.PriceListItemSerializerCreate


class PriceListItemUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PriceListItem.objects.all()
    serializer_class = serializers.PriceListItemSerializerUpdate


class OrganizationPriceListList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationPriceList.objects.all()
    serializer_class = serializers.OrganizationPriceListSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(OrganizationPriceListList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class OrganizationPriceListRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationPriceList.objects.all()
    serializer_class = serializers.OrganizationPriceListSerializer


class OrganizationPriceListCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationPriceList.objects.all()
    serializer_class = serializers.OrganizationPriceListSerializerCreate


class OrganizationPriceListUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.OrganizationPriceList.objects.all()
    serializer_class = serializers.OrganizationPriceListSerializerUpdate
