# -*- coding: utf-8 -*-

import datetime

from django.conf import settings
from django.db import models


class PriceListQuerySet(models.QuerySet):
    def valids(self):
        return self.filter(
            price_list_type=settings.PRICE_PRICE_LIST_STREET_PRICE,
            status=1,
            date_begin__lte=datetime.date.today, date_end__gte=datetime.date.today,
        )


class PriceListManager(models.Manager):
    def get_queryset(self):
        return PriceListQuerySet(self.model, using=self._db)

    def valids(self):
        return self.get_queryset().valids()


class PriceListItemQuerySet(models.QuerySet):
    def valids(self):
        return self.filter(
            price_list__price_list_type=settings.PRICE_PRICE_LIST_STREET_PRICE,
            price_list__status=1,
            price_list__date_begin__lte=datetime.date.today, price_list__date_end__gte=datetime.date.today,
            status=1,
        )


class PriceListItemManager(models.Manager):
    def get_queryset(self):
        return PriceListItemQuerySet(self.model, using=self._db)

    def valids(self):
        return self.get_queryset().valids()
